@@ -2,15 +2,15 @@ try:
     import tktooltip
 except ImportError:
     pass
-from typing import Literal
 import tkinter as tk
 import tkinter.ttk as ttk
-import tkinter.tix as tix
-from tkdev.devresize import DevResize
-from tkdev.devicon import Icon_Empty
 from ctypes import windll
-from os import environ
 from enum import Enum
+from typing import Literal
+
+from tkdev.devicon import Icon_Empty
+from tkdev.devresize import DevResize
+
 try:
     from win32gui import *
     from win32con import *
@@ -29,9 +29,11 @@ dwm = windll.dwmapi
 windll.shcore.SetProcessDpiAwareness(1)
 ScaleFactor = windll.shcore.GetScaleFactorForDevice(0)
 
-taskbar_height = GetMonitorInfo(MonitorFromPoint((0, 0))).get("Monitor")[3] - \
-                 GetMonitorInfo(MonitorFromPoint((0, 0))).get("Work")[3]
-
+try:
+    taskbar_height = GetMonitorInfo(MonitorFromPoint((0, 0))).get("Monitor")[3] - \
+                     GetMonitorInfo(MonitorFromPoint((0, 0))).get("Work")[3]
+except:
+    pass
 Auto = "auto"
 Light = "light"
 Dark = "dark"
@@ -39,22 +41,26 @@ Dark = "dark"
 DWMWA_USE_IMMERSIVE_DARK_MODE = 20
 
 
-def Install(Library, Basic=True):
-    import os, sys
+def Install(Library, Basic=True, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
+    import os
+    import sys
     if Basic:
-        print(f"{sys.executable} -m pip install {Library} -i https://pypi.tuna.tsinghua.edu.cn/simple/")
-        os.system(f"{sys.executable} -m pip install {Library}  -i https://pypi.tuna.tsinghua.edu.cn/simple/")
+        print(f"{sys.executable} -m pip install {Library} -i {Pypi}")
+        os.system(f"{sys.executable} -m pip install {Library}  -i {Pypi}")
+        print(f"{sys.executable} -m pip install {Library}  -i {Pypi} --upgrade")
+        os.system(f"{sys.executable} -m pip install {Library}  -i {Pypi} --upgrade")
     else:
         print(f"{sys.executable} -m pip install {Library}")
         os.system(f"{sys.executable} -m pip install {Library}")
+        os.system(f"{sys.executable} -m pip install {Library} --upgrade")
 
 
-def Install_ALL():
-    Install("tkinter-tooltip")
-    Install("pywin32")
-    Install("win32mica")
-    Install("BlurWindow")
-    Install("darkdetect")
+def Install_ALL(Basic=True, Pypi="https://pypi.tuna.tsinghua.edu.cn/simple/"):
+    Install("tkinter-tooltip", Basic=Basic, Pypi=Pypi)
+    Install("pywin32", Basic=Basic, Pypi=Pypi)
+    Install("win32mica", Basic=Basic, Pypi=Pypi)
+    Install("BlurWindow", Basic=Basic, Pypi=Pypi)
+    Install("darkdetect", Basic=Basic, Pypi=Pypi)
 
 
 class DWMWINDOWATTRIBUTE(Enum):
@@ -109,7 +115,7 @@ def window_long(window: tk.Tk, long):
         hwnd = GetParent(window.winfo_id())
         res = SetWindowLong(hwnd, GWL_STYLE, GetWindowLong(hwnd, GWL_STYLE) & ~long)
 
-    self.after(1, long)
+    window.after(1, long)
 
 
 def window_ex_long(window: tk.Tk, long):
@@ -153,7 +159,8 @@ def window_mica_dark(window: tk.Tk):
 
 def window_pos_bottom_right(window: tk.Tk, padx: int = 15, pady: int = 15):
     window.after(1, lambda: window.geometry(
-        f"+{window.winfo_screenwidth() - window.winfo_width() - padx - 10}+{window.winfo_screenheight() - taskbar_height - window.winfo_height() - pady - 35}"))
+        f"+{window.winfo_screenwidth() - window.winfo_width() - padx - 10}+"
+        f"{window.winfo_screenheight() - taskbar_height - window.winfo_height() - pady - 35}"))
 
 
 def window_pos_bottom_left(window: tk.Tk, padx: int = 15, pady: int = 15):
@@ -631,35 +638,38 @@ class DevSubWindow(tk.Frame):
         self.place(x=0, y=0, width=300, height=300)
 
 
-class DevToolTip(tktooltip.ToolTip):
-    def __init__(self, widget: tk.Widget,
-                 msg: str = "",
-                 delay: float = 1.0,
-                 follow: bool = True,
-                 refresh: float = 1.0,
-                 x_offset: int = +10,
-                 y_offset: int = +10,
-                 parent_kwargs: dict = {"bg": "black", "padx": 1, "pady": 1},
-                 foreground: str = "#ffffff", background="#1c1c1c",
-                 **message_kwargs):
-        """
-        本人比较懒，不想写，就用了tkinter-tooltip组件，请不要喷我
+try:
+    class DevToolTip(tktooltip.ToolTip):
+        def __init__(self, widget: tk.Widget,
+                     msg: str = "",
+                     delay: float = 1.0,
+                     follow: bool = True,
+                     refresh: float = 1.0,
+                     x_offset: int = +10,
+                     y_offset: int = +10,
+                     parent_kwargs: dict = {"bg": "black", "padx": 1, "pady": 1},
+                     foreground: str = "#ffffff", background="#1c1c1c",
+                     **message_kwargs):
+            """
+            本人比较懒，不想写，就用了tkinter-tooltip组件，请不要喷我
 
-        :param widget:
-        :param msg:
-        :param delay:
-        :param follow:
-        :param refresh:
-        :param x_offset:
-        :param y_offset:
-        :param parent_kwargs:
-        :param foreground:
-        :param background:
-        :param message_kwargs:
-        """
-        super(DevToolTip, self).__init__(widget=widget, msg=msg, delay=delay, follow=follow, refresh=refresh,
-                                         x_offset=x_offset, y_offset=y_offset, parent_kwargs=parent_kwargs,
-                                         fg=foreground, bg=background)
+            :param widget:
+            :param msg:
+            :param delay:
+            :param follow:
+            :param refresh:
+            :param x_offset:
+            :param y_offset:
+            :param parent_kwargs:
+            :param foreground:
+            :param background:
+            :param message_kwargs:
+            """
+            super(DevToolTip, self).__init__(widget=widget, msg=msg, delay=delay, follow=follow, refresh=refresh,
+                                             x_offset=x_offset, y_offset=y_offset, parent_kwargs=parent_kwargs,
+                                             fg=foreground, bg=background)
+except:
+    pass
 
 
 class DevTitleBar(tk.Frame):
